Panda3D Analyze
===============
![GitHub issues](https://img.shields.io/github/issues/NxtStudios/p3d-analyze?style=for-the-badge)
![PyPI - Status](https://img.shields.io/pypi/status/panda3d_analyze?style=for-the-badge)
![Engine](https://img.shields.io/static/v1?style=for-the-badge&label=Engine&message=Panda3D&color=red)


## Dependencies
* Python 3.7
* Panda3d 1.10.0 or newer

## License
p3d-analyze is available under the MIT license. A copy of this license can be found with the source code. If one was not provided its available <a href="https://github.com/NxtStudios/p3d-analyze/blob/master/LICENSE">here</a>
